pub struct CompressionThreshold(pub i32);Expand description
How large a packet should be before it is compressed by the packet encoder.
If the inner value is >= 0, then packets with encoded lengths >= to this value will be compressed. If the value is negative, then compression is disabled and no packets are compressed.
Tuple Fields
0: i32Implementations
Sourceimpl CompressionThreshold
impl CompressionThreshold
Sourcepub const DEFAULT: CompressionThreshold
pub const DEFAULT: CompressionThreshold
No compression.