pub struct DefaultPlugins;Expand description
This plugin group will add all the default plugins for a ChunkEdge application.
DefaultPlugins obeys Cargo feature flags. Users may exert control over
this plugin group by disabling default-features in their Cargo.toml and
enabling only those features that they wish to use.